library(gnlm)
library(event)

surv <- read.surv("cancer.dat",skip=5,nline=1,cum=F,all=F)
tt <- surv[[1]]
cens <- surv[[2]]
treat <- as.factor(c(rep(1,47),rep(2,31),rep(3,38)))
nobs <- NULL
for(i in tt) nobs <- c(nobs,length(i))
y <- unlist(tt)
y1 <- c(1,y[1:291])
cs <- rep(1,sum(nobs))
cs[cumsum(nobs)] <- cens
id <- NULL
for(i in 1:length(tt))id <- c(id,rep(i,length(tt[[i]])))
tr <- NULL
for(i in 1:length(tt))tr <- c(tr,rep(as.numeric(treat[i]),length(tt[[i]])))
tr <- as.factor(tr)
nr <- NULL
for(i in tt)nr <- c(nr,1:length(i))
wt <- nr>1
sh <- log(y1)*wt
tt <- restovec(tt,censor=cens)

if(interactive()){
postscript("cancer.eps",height=5)
par(mfrow=c(1,2))
plot(km(y[nr==1],group=tr[nr==1],censor=cs[nr==1]),main="",xlab="Months",
	ylab="Nonrecurrence probability")
plot(km(y[nr>1],group=tr[nr>1],censor=cs[nr>1]),xlim=c(0,60),main="",
	xlab="Months",ylab="")
}

ly <- cbind(log(y),cs)
delta <- 1/y
y <- cbind(y,cs)
mu <- function(p,linear) exp(linear)
shape <- function(p) sh
# independence
gnlr(y,"gamma",mu=mu,pmu=2,pshape=0.2,linear=~1,wt=wt)
gnlr(y,"gamma",mu=mu,pmu=c(2.4,0,0),pshape=0.2,linear=~tr,wt=wt)
gnlr(y,"gamma",mu=mu,pmu=c(2.4,-0.4),pshape=0.2,linear=~tr==2,wt=wt)
gnlr(y,"gamma",mu=mu,pmu=c(2.4,-0.4,0),pshape=0.2,linear=~(tr==2)+I(nr-1),wt=wt)

# conditional exponential family
gnlr(y,"gamma",mu=~sh,pmu=c(10,1),shape=shape,wt=wt)
gnlr(y,"gamma",mu=~sh+tr,pmu=c(10,0,-4,-1),shape=shape,wt=wt)
gnlr(y,"gamma",mu=~sh+I(nr-1),pmu=c(10,0,-0.5),shape=shape,wt=wt)

# autoregression
gnlr(y,"gamma",mu=~y1,pmu=c(11,0.2),psh=0.2,wt=wt)
gnlr(y,"gamma",mu=~y1+tr,psh=0.2,pmu=c(11.6,0.6,-4.5,0),wt=wt)
gnlr(y,"gamma",mu=~y1+(tr==2),psh=0.2,pmu=c(11.6,0.6,-4.5),wt=wt)
gnlr(y,"gamma",mu=~y1+(tr==2)+I(nr-1),psh=0.1,pmu=c(10,2,-0.1,-1),wt=wt)

# autoregression on log
gnlr(y,"gamma",mu=mu,linear=~sh,pmu=c(2.4,0.02),psh=0.2,wt=wt)
gnlr(y,"gamma",mu=mu,linear=~sh+tr,psh=0.2,pmu=c(2.5,0.04,-0.4,0),wt=wt)
gnlr(y,"gamma",mu=mu,linear=~sh+(tr==2),psh=0.2,pmu=c(2.4,0.04,-0.4),wt=wt)
gnlr(y,"gamma",mu=mu,linear=~sh+(tr==2)+I(nr-1),psh=0.1,
	pmu=c(2.5,0.03,-0.4,0),wt=wt)

# conditional model with scale proportional to y_t-1
shape <- function(p) sh*p[1]
gnlr(y,"gamma",mu=~sh,pmu=c(11,0.2),shape=shape,psh=0.1,wt=wt)
gnlr(y,"gamma",mu=~sh+tr,pmu=c(12,0.5,-4.5,0.7),shape=shape,,psh=0.1,wt=wt)
gnlr(y,"gamma",mu=~sh+(tr==2),pmu=c(12,0.5,-4.5),shape=shape,,psh=0.1,wt=wt)
gnlr(y,"gamma",mu=~sh+(tr==2)+I(nr-1),pmu=c(12.2,0.5,-4.8,-0.09),shape=shape,
	psh=0.1,wt=wt)

# full model
# independence
gnlr(y,"gamma",mu=mu,linear=~1,pmu=3,psh=c(-0.2))
gnlr(y,"gamma",mu=mu,linear=~tr,pmu=c(3,0,0),psh=c(-0.2))
gnlr(y,"gamma",mu=mu,linear=~(tr==3),pmu=c(3,0),psh=c(-0.2))
gnlr(y,"gamma",mu=mu,linear=~(tr==3)+I(nr-1),pmu=c(3,0,0),psh=c(-0.2))

# exponential dispersion model
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1))
shape <- function(p) p[1]*(nr==1)+sh*p[2]*(nr>1)
gnlr(y,"gamma",mu=mu,pmu=c(3.6,2.4,0.2),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+
	p[4]*(tr==2)+p[5]*(tr==3))
gnlr(y,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+p[4]*(tr==2))
gnlr(y,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+
	p[4]*(tr==2)+p[5]*(nr-1))
gnlr(y,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+p[2]*(nr>1)+p[3]*(tr==2)+p[4]*(nr-1))
gnlr(y,"gamma",mu=mu,pmu=c(3.6,2.4,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+p[2]*(nr>1)+p[3]*(tr==2)*(nr>1)
	+p[4]*(tr==1)*(nr==1)+p[5]*(nr-1))
gnlr(y,"gamma",mu=mu,pmu=c(3.7,2.8,-0.4,0.7,-0.1),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]+p[2]*(tr==2)+p[3]*(nr-1))
gnlr(y,"gamma",mu=mu,pmu=c(3,0.4,0),shape=shape,psh=c(-0.4,0.1))

print(ze <- kalsurv(tt,pinit=1.5,preg=1,dep="frailty"))
print(zeb <- kalsurv(tt,pinit=1.5,preg=1,pbirth=0,dep="frailty"))
print(zet <- kalsurv(tt,pinit=1.5,preg=c(1,0,0),ccov=~treat,dep="frailty"))
print(zetb <- kalsurv(tt,pinit=1.5,preg=c(1,0,0),ccov=~treat,pbirth=0,
	dep="frailty"))
print(zw <- kalsurv(tt,pinit=0.1,preg=1,psh=1,intensity="Weibull",
	dep="frailty"))
print(zwb <- kalsurv(tt,pinit=1.5,preg=1,psh=1,pbirth=0,intensity="Weibull",
	dep="frailty"))
print(zwt <- kalsurv(tt,pinit=1.5,psh=1,preg=c(1,0,0),
	ccov=~treat,intensity="Weibull",dep="frailty"))
print(zwtb <- kalsurv(tt,pinit=0.1,psh=1,preg=c(1,0,0),
	ccov=~treat,pbirth=0,intensity="Weibull",dep="frailty"))
print(zln <- kalsurv(tt,pinit=0.1,preg=1,psh=1,
	intensity="log normal",dep="frailty"))
print(zlnb <- kalsurv(tt,pinit=1.5,preg=1,psh=1,
	pbirth=0,intensity="log normal",dep="frailty"))
print(zlnt <- kalsurv(tt,pinit=1.5,psh=1,preg=c(1,0,0),
	ccov=~treat,intensity="log normal",dep="frailty"))
print(zlntb <- kalsurv(tt,pinit=0.1,psh=1,preg=c(1,0,0),
	ccov=~treat,pbirth=0,intensity="log normal",dep="frailty"))

print(zei <- kalsurv(tt,pinit=1.5,preg=1,dep="independence"))
print(zeib <- kalsurv(tt,pinit=1.5,preg=1,dep="independence",pbirth=0))
print(zee <- kalsurv(tt,pinit=1.5,pdep=0.1,preg=1,dep="serial",upd="event"))
print(zeeb <- kalsurv(tt,pinit=1.5,pdep=0.5,preg=1,
	pbirth=0,dep="serial",upd="event"))
print(zes <- kalsurv(tt,pinit=1.5,pdep=0.1,preg=1,dep="serial",upd="Markov"))
print(zesb <- kalsurv(tt,pinit=1.5,pdep=0.5,preg=1,
	pbirth=0,dep="serial",upd="Markov"))
print(zec <- kalsurv(tt,pinit=1.5,pdep=0.5,preg=1,dep="serial",upd="count"))
#print(zeh <- kalsurv(tt,pinit=1.5,pdep=0.1,preg=1,
#	dep="serial",upd="cumulated"))
#print(zek <- kalsurv(tt,pinit=1.5,pdep=0.01,preg=1,dep="serial",upd="kalman"))

print(zeit <- kalsurv(tt,pinit=1.5,dep="independence",preg=c(1,0,0),
	ccov=~treat))
print(zeitb <- kalsurv(tt,pinit=1.5,dep="independence",
	pbirth=0,preg=c(1,0,0),ccov=~treat))
print(zeet <- kalsurv(tt,pinit=1.5,pdep=0.5,upd="event",
	dep="serial",preg=c(1,0,0),ccov=~treat))
print(zeetb <- kalsurv(tt,pinit=0.5,pdep=0.5,
	pbirth=0,dep="serial",upd="event",preg=c(1,0,0),ccov=~treat))
print(zest <- kalsurv(tt,pinit=0.5,pdep=0.5,upd="Markov",
	dep="serial",preg=c(1,0,0),ccov=~treat))
print(zestb <- kalsurv(tt,pinit=0.8,pdep=0.5,
	pbirth=0,dep="serial",upd="Markov",preg=c(1,0,0),ccov=~treat))
print(zect <- kalsurv(tt,pinit=0.8,pdep=0.5,upd="count",
	dep="serial",preg=c(1,0,0),ccov=~treat))
print(zectb <- kalsurv(tt,pinit=0.8,pdep=0.5,upd="count",
	dep="serial",pbirth=0,preg=c(1,0,0),ccov=~treat))
print(zeht <- kalsurv(tt,pinit=1.5,pdep=0.5,
	dep="serial",upd="cumulated",preg=c(2,1,3),ccov=~treat))
print(zekt <- kalsurv(tt,pinit=0.8,pdep=0.5,upd="kalman",
	dep="serial",preg=c(1,0,0),ccov=~treat))

print(zwi <- kalsurv(tt,pinit=0.8,preg=1,psh=1,
	dep="independence",intensity="Weibull"))
print(zwe <- kalsurv(tt,pinit=0.7,pdep=0.5,preg=3,psh=4.5,
	dep="serial",upd="event",intensity="Weibull"))
print(zwm <- kalsurv(tt,pinit=0.93,pdep=0.4,preg=2.8,psh=1.2,
	dep="serial",upd="Markov",intensity="Weibull",stepmax=5))
print(zwc <- kalsurv(tt,pinit=0.8,pdep=0.5,preg=1,psh=1,
	dep="serial",upd="count",intensity="Weibull"))
print(zwh <- kalsurv(tt,pinit=0.8,pdep=0.5,preg=1,psh=1,
	dep="serial",upd="cumulated",intensity="Weibull"))
#print(zwk <- kalsurv(tt,pinit=0.8,pdep=0.5,preg=1,psh=1,
#	dep="serial",upd="kalman",intensity="Weibull"))

print(zwit <- kalsurv(tt,pinit=0.8,psh=1,
	dep="independence",intensity="Weibull",preg=c(1,0,0),ccov=~treat))
print(zwitb <- kalsurv(tt,pinit=0.8,psh=1,pbirth=0,
	dep="independence",intensity="Weibull",preg=c(1,0,0),ccov=~treat))
print(zwet <- kalsurv(tt,pinit=0.6,pdep=0.6,psh=4.5,dep="serial",
	upd="event",intensity="Weibull",preg=c(3,0,0),ccov=~treat))
print(zwetb <- kalsurv(tt,pinit=0.8,pdep=0.01,psh=4.5,dep="serial",
	pbirth=0,upd="event",intensity="Weibull",preg=c(3,0.5,0.7),
	ccov=~treat))
print(zwmt <- kalsurv(tt,pinit=0.8,pdep=0.01,psh=4.5,dep="serial",
	upd="Markov",intensity="Weibull",preg=c(3,0,0),ccov=~treat))
print(zwmtb <- kalsurv(tt,pinit=0.8,pdep=0.01,psh=4.5,dep="serial",
	pbirth=0,upd="Markov",intensity="Weibull",preg=c(3,0.5,0.7),
	ccov=~treat))
print(zwct <- kalsurv(tt,pinit=0.8,pdep=0.5,psh=1, dep="serial",
	upd="count",intensity="Weibull",preg=c(1,0,0),ccov=~treat))
print(zwctb <- kalsurv(tt,pinit=0.8,pdep=0.5,psh=1, dep="serial",
	pbirth=0,upd="count",intensity="Weibull",preg=c(1,0,0),ccov=~treat))
print(zwht <- kalsurv(tt,pinit=0.8,pdep=0.6,psh=1,dep="serial",
	upd="cumulated",intensity="Weibull",preg=c(1,0,0),ccov=~treat))
print(zwkt <- kalsurv(tt,pinit=0.1,pdep=0.9,psh=0.8,dep="serial",
	upd="kalman",intensity="Weibull",preg=c(1,0.5,0.7),ccov=~treat))

print(zgit <- kalsurv(tt,pinit=1,psh=4,dep="independence",
	intensity="gamma",preg=c(0.5,-0.156,-0.186),ccov=~treat))
print(zgitb <- kalsurv(tt,pinit=2.94,psh=3.73,pbirth=-0.1,
	dep="independence",intensity="gamma",preg=c(0.6,-0.24,-0.34),
	ccov=~treat))

print(zlni <- kalsurv(tt,pinit=0.8,psh=1,
	dep="independence",intensity="log normal",preg=1))
print(zlnit <- kalsurv(tt,pinit=0.8,psh=1,
	dep="independence",intensity="log normal",preg=c(1,0,0),ccov=~treat))
print(zlnitb <- kalsurv(tt,pinit=0.8,psh=1,
	pbirth=0,dep="independence",intensity="log normal",preg=c(1,0,0),
	ccov=~treat))
print(zlnm <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="Markov",intensity="log normal",preg=4))
print(zlnmt <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="Markov",intensity="log normal",preg=c(4,0.1,0.2),ccov=~treat))
print(zlnmtb <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	pbirth=0,upd="Markov",intensity="log normal",preg=c(4,0.1,0.2),
	ccov=~treat))
print(zlnc <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="count",intensity="log normal",preg=4))
print(zlncb <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	pbirth=0,upd="count",intensity="log normal",preg=4))
print(zlnct <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	upd="count",intensity="log normal",preg=c(4,0.1,0.2),ccov=~treat))
print(zlnctb <- kalsurv(tt,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	pbirth=0,upd="count",intensity="log normal",preg=c(4,0.1,0.2),
	ccov=~treat))

print(zllit <- kalsurv(tt,pinit=0.8,psh=1,
	dep="independence",intensity="log logistic",preg=c(1,0,0),ccov=~treat))
print(zllitb <- kalsurv(tt,pinit=0.8,psh=1,
	pbirth=0,dep="independence",intensity="log logistic",preg=c(1,0,0),
	ccov=~treat))

print(zlcit <- kalsurv(tt,pinit=0.8,psh=0.72,dep="independence",
	intensity="log Cauchy",preg=c(1,0.1,0.4),ccov=~treat))
print(zlcitb <- kalsurv(tt,pinit=0.8,psh=0.72,pbirth=-0.1,
	dep="independence",intensity="log Cauchy",preg=c(1.8,-0.1,-0.4),
	ccov=~treat))

mu <- function(p) exp(p[1])
gnlr(y,"exponential",pmu=3,mu=mu)
gnlr(y,"Weibull",pmu=3,pshape=0,mu=mu)
gnlr(y,"gamma",pmu=3,pshape=0,mu=mu)
gnlr(ly,"normal",pmu=2,pshape=0.5,delta=delta)
gnlr3(y,"Burr",pmu=2,pshape=0.6,pfam=-0.3,mu=mu)
tr2 <- as.numeric(treat[covind(tt)])==2
tr3 <- as.numeric(treat[covind(tt)])==3
mu <- function(p) exp(p[1]+p[2]*tr2+p[3]*tr3)
gnlr(y,"exponential",pmu=c(8,-1,-1),mu=mu)
gnlr(y,"Weibull",pmu=c(8,-1,-1),pshape=0,mu=mu)
gnlr(ly,"normal",pmu=c(2,0,0),pshape=0.11,mu=~tr2+tr3,delta=delta)
gnlr3(y,"Burr",pmu=c(5,0,0),pshape=0.6,pfam=-0.3,mu=mu)
birth <- log(sequence(nobs(tt)))
mu <- function(p) exp(p[1]+p[2]*tr2+p[3]*tr3+p[4]*birth)
gnlr(y,"exponential",pmu=c(8,-1,0,0),mu=mu)
gnlr(y,"Weibull",pmu=c(8,-1,0,0),pshape=0,mu=mu)
gnlr(ly,"normal",pmu=c(2,0,0,0),pshape=0.11,mu=~tr2+tr3+birth,delta=delta)
gnlr3(y,"Burr",pmu=c(5,0,0,0),pshape=0.6,pfam=-0.3,mu=mu)

# number of unique uncensored observations = 49
length(unique(y))

# number of ties = 0
sum(y==0)

# number censored/number = 0/62
length(cens)-sum(cens)
length(cens)
