library(gnlm)
library(event)

surv <- read.surv("cancer.dat",skip=5,nline=1,cum=F,all=F)
# lagged times, observation numbers, and weights
y1 <- sh <- nr <- wt <- list()
for(i in surv[[1]]){
	nr <- c(nr,list(1:length(i)))
	wt <- c(wt,list((1:length(i))>1))
	y1 <- c(y1,list(if(length(i)==1) 1
		else c(1,i[1:(length(i)-1)])))
	sh <- c(sh,list(log(y1[[length(y1)]])))}
treat <- as.factor(c(rep(1,47),rep(2,31),rep(3,38)))
tvc <- tvctomat(y1,name="y1")
tvc <- tvctomat(sh,name="sh",old=tvc)
tvc <- tvctomat(nr,name="nr",old=tvc)
reps <- rmna(restovec(surv[[1]],censor=surv[[2]],weight=wt),
	ccov=tcctomat(~treat),tvcov=tvc)

if(interactive()){
postscript("cancer.eps",height=5)
nr <- sequence(nobs(reps))
tr <- treat[covind(reps)]
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(response(reps)[nr==1,1],group=tr[nr==1],
	censor=response(reps)[nr==1,2]),main="",xlab="Months",
	ylab="Non-recurrence probability",xaxt="n")
axis(1,c(0,20,40,60))
plot(km(response(reps)[nr>1,1],group=tr[nr>1],
	censor=response(reps)[nr>1,2]),xlim=c(0,60),main="",
	xlab="Months",ylab="",xaxt="n")
axis(1,c(0,20,40,60))
legend(20,1,legend=c("Placebo","Pyridoxine","Thiotepa"),lty=1:3,bty="n")
dev.off()
}

mu <- function(p,linear) exp(linear)
shape <- function(p) sh

# independence
gnlr(reps,"gamma",mu=~1,pmu=7,pshape=0.2)
gnlr(reps,"gamma",mu=mu,pmu=c(2.4,0,0),pshape=0.2,linear=~treat2+treat3)

# conditional exponential family
gnlr(reps,"gamma",mu=~sh,pmu=c(9,0.4),shape=shape)
gnlr(reps,"gamma",mu=~sh+treat2+treat3,pmu=c(11,-0.1,-3.5,-1),shape=shape)

# autoregression
gnlr(reps,"gamma",mu=~y1,pmu=c(11,0.2),psh=0.2)
gnlr(reps,"gamma",mu=~y1+treat2+treat3,psh=0.2,pmu=c(11.6,0.6,-4.5,0))

# autoregression on log
gnlr(reps,"gamma",mu=mu,linear=~sh,pmu=c(2.4,0.02),psh=0.2)
gnlr(reps,"gamma",mu=mu,linear=~sh+treat2+treat3,psh=0.2,
	pmu=c(2.5,0.04,-0.4,0))

# full model
reps <- rmna(restovec(surv[[1]],censor=surv[[2]],name="y"),
	ccov=tcctomat(~treat),tvcov=tvc)
# independence
gnlr(reps,"gamma",mu=~1,pmu=20,psh=c(-0.2))
gnlr(reps,"gamma",mu=mu,linear=~treat2+treat3,pmu=c(3,0,0),psh=c(-0.2))

# exponential dispersion model
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1))
shape <- function(p) p[1]*(nr==1)+sh*p[2]*(nr>1)
gnlr(reps,"gamma",mu=mu,pmu=c(3.6,2.4,0.2),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+
	p[4]*treat2+p[5]*treat3)
gnlr(reps,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+p[4]*treat2)
gnlr(reps,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+(p[2]+p[3]*y1)*(nr>1)+
	p[4]*treat2+p[5]*(nr-1))
gnlr(reps,"gamma",mu=mu,pmu=c(3.6,2.4,0.2,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+p[2]*(nr>1)+p[3]*treat2+p[4]*(nr-1))
gnlr(reps,"gamma",mu=mu,pmu=c(3.6,2.4,0.4,0),shape=shape,psh=c(-0.4,0.1))
mu <- function(p) exp(p[1]*(nr==1)+p[2]*(nr>1)+p[3]*treat2*(nr>1)
	+p[4]*(1-treat2)*(1-treat3)*(nr==1)+p[5]*(nr-1))
gnlr(reps,"gamma",mu=mu,pmu=c(3.7,2.8,-0.4,0.7,-0.1),shape=shape,
	psh=c(-0.4,0.1))
