library(gnlm)
library(event)

tt <- read.list("mines.dat",skip=8,nline=1)
cens <- rep(0,7)
id <- wt <- cn <- birth <- birtht <- te <- NULL
for(i in 1:7){
	tmp <- NULL
	for(j in 1:length(tt[[i]])){
		if(tt[[i]][j]>0) tmp <- c(tmp,1)
		else tmp[length(tmp)] <- tmp[length(tmp)]+1}
	wt <- c(wt,tmp)
	birtht <- c(birtht,c(0,cumsum(tmp)[1:(length(tmp)-1)]))
	birth <- c(birth,1:length(tt[[i]][tt[[i]]>0]))
	id <- c(id,rep(i,length(tt[[i]][tt[[i]]>0])))
	te <- c(te,cumsum(tt[[i]]))
	cn <- c(cn,c(0,rep(1,length(tt[[i]])-2),0))}
id <- as.factor(id)

if(interactive()){
times <- events <- list()
for(i in 1:7){
	tmp <- NULL
	for(j in 1: length(tt[[i]])){
		if(tt[[i]][j]>0) tmp <- c(tmp,1)
		else tmp[length(tmp)] <- tmp[length(tmp)]+1}
	events <- c(events,list(tmp))
	times <- c(times,list(tt[[i]][tt[[i]]>0]))}
postscript("mines.eps",height=5)
par(mfrow=c(1,2),font.main=1)
cprocess(times,number=T,ylim=c(0,65),xlab="Days",main="Days with events")
cprocess(times,events,number=T,ylim=c(0,65),ylab="",xlab="Days",
	main="Total accidents")
}

tt <- restovec(tt,cens=cens)
te <- te[response(tt)>0]
y <- cbind(response(tt)[response(tt)>0],cn[response(tt)>0])

print(ze <- kalsurv(tt,pinit=1.5,preg=1,dep="frailty"))
print(zeb <- kalsurv(tt,pinit=1.5,preg=1,pbirth=0,dep="frailty"))
print(zw <- kalsurv(tt,pinit=1.5,preg=1,psh=1,intensity="Weibull",
	dep="frailty"))
print(zwb <- kalsurv(tt,pinit=1.5,preg=1,psh=1,pbirth=0,
	intensity="Weibull",dep="frailty"))
print(zg <- kalsurv(tt,pinit=1.5,preg=1,psh=1,intensity="gamma",dep="frailty"))
print(zgb <- kalsurv(tt,pinit=0.3,preg=1,psh=1.5,pbirth=0,
	intensity="gamma",dep="frailty"))

print(zei <- kalsurv(tt,pinit=1.5,preg=1,dep="independence"))
print(zeib <- kalsurv(tt,pinit=1.5,preg=1,pbirth=0,dep="independence"))
print(zee <- kalsurv(tt,pinit=1.1,pdep=0.999,preg=1,dep="serial",upd="event"))
print(zeeb <- kalsurv(tt,pinit=0.1,pdep=0.99,preg=1,
	pbirth=0,dep="serial",upd="event"))
print(zem <- kalsurv(tt,pinit=1.1,pdep=0.5,preg=1,dep="serial",upd="Markov"))
print(zemb <- kalsurv(tt,pinit=1.1,pdep=0.5,preg=1,
	pbirth=0,dep="serial",upd="Markov"))
print(zec <- kalsurv(tt,pinit=1.1,pdep=0.1,preg=1,dep="serial",upd="count"))
print(zeh <- kalsurv(tt,pinit=0.15,pdep=0.97,preg=2,
	dep="serial",upd="cumulated"))
print(zek <- kalsurv(tt,pinit=0.5,pdep=0.9,preg=2,dep="serial",upd="kalman"))

#print(zwi <- kalsurv(tt,pinit=0.5,preg=7,psh=1,
#	dep="independence",intensity="Weibull",print.level=2))
#print(zwe <- kalsurv(tt,pinit=0.5,pdep=0.01,preg=7,psh=1,
#	dep="serial",upd="event",intensity="Weibull",print.level=2))
#print(zwm <- kalsurv(tt,pinit=0.5,pdep=0.9,preg=9,psh=1,
#	dep="serial",upd="Markov",intensity="Weibull"))
#print(zwc <- kalsurv(tt,pinit=0.5,pdep=0.5,preg=9,psh=1,
#	dep="serial",upd="count",intensity="Weibull"))
print(zwh <- kalsurv(tt,pinit=0.5,pdep=0.5,preg=7,psh=1,
	dep="serial",upd="cumulated",intensity="Weibull"))
print(zwk <- kalsurv(tt,pinit=0.7,pdep=0.5,preg=1,psh=1,
	dep="serial",upd="kalman",intensity="Weibull"))

print(zgi <- kalsurv(tt,pinit=0.62,preg=0.79,psh=2.06,
	dep="independence",intensity="gamma"))
print(zgm <- kalsurv(tt,pinit=1,pdep=0.5,preg=0.7,psh=2.1,
	dep="serial",upd="Markov",intensity="gamma"))
print(zlnm <- kalsurv(tt,pinit=0.4,pdep=0.96,preg=3.9,psh=1.65,
	dep="serial",upd="Markov",intensity="log normal"))
print(zllm <- kalsurv(tt,pinit=0.4,pdep=0.96,preg=3.9,psh=1.65,
	dep="serial",upd="Markov",intensity="log logistic"))
print(zlcm <- kalsurv(tt,pinit=0.4,pdep=0.96,preg=3.9,psh=1.65,
	dep="serial",upd="Markov",intensity="log Cauchy"))

mu <- function(p,linear) exp(linear)
mub <- function(p) exp(p[1]+p[2]*birth)
mubt <- function(p) exp(p[1]+p[2]*birtht)
mut <- function(p) exp(p[1]+p[2]*te)

gnlr(y,"exponential",pmu=5,wt=wt)
gnlr(y,"Weibull",pmu=5,pshape=0,wt=wt)
gnlr(y,"Weibull",pmu=c(5,rep(0,6)),pshape=0.2,mu=mu,linear=~id,wt=wt)
gnlr(y,"gamma",pmu=5,pshape=0,wt=wt)
gnlr(y,"Pareto",pmu=5,pshape=1,wt=wt)

gnlr(y,"exponential",pmu=c(3,0),mu=mub,wt=wt)
gnlr(y,"Weibull",pmu=c(3,-0.1),pshape=-0.4,mu=mub,wt=wt)
gnlr(y,"Weibull",pmu=c(8,-0.1,rep(0,6)),pshape=0.2,mu=mu,
	linear=~birth+id,wt=wt)
gnlr(y,"gamma",pmu=c(8,-0.1),pshape=0.2,mu=mub,wt=wt)
gnlr(y,"gamma",pmu=c(8,-0.1,rep(0,6)),pshape=0.2,mu=mu,linear=~birth+id,wt=wt)
gnlr(y,"Pareto",pmu=c(3,-0.1),pshape=0.4,mu=mub,wt=wt)
gnlr(y,"exponential",pmu=c(3,0),mu=mubt,wt=wt)
gnlr(y,"Weibull",pmu=c(3,-0.1),pshape=-0.4,mu=mubt,wt=wt)
gnlr(y,"gamma",pmu=c(8,-0.1),pshape=0.2,mu=mubt,wt=wt)
gnlr(y,"Pareto",pmu=c(3,-0.1),pshape=0.4,mu=mubt,wt=wt)

famt <- function(p) p[1]+p[2]*te
famb <- function(p) p[1]+p[2]*birth
fambt <- function(p) p[1]+p[2]*birtht
gnlr3(y,"Burr",pmu=5,pshape=0,pfam=0,wt=wt)
gnlr3(y,"Burr",pmu=c(3,rep(0,6)),pshape=-0.4,mu=mu,linear=~id,pfam=1,wt=wt)
gnlr3(y,"Burr",pmu=c(2.5,0),pshape=0.3,mu=mut,pfam=1.4,wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=0.3,mu=mut,fam=famt,pfam=c(9,-0.04),wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=c(0.3,0.001),mu=mut,sh=famt,fam=famt,
	pfam=c(9,-0.04),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mub,pfam=1,wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1,rep(0,6)),pshape=-0.4,mu=mu,linear=~birth+id,
	pfam=1,wt=wt)
gnlr3(y,"Burr",pmu=3,pshape=-0.4,fam=famt,pfam=c(2,-0.01),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mub,fam=famt,pfam=c(2,-0.01),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mut,fam=famt,pfam=c(2,-0.01),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mub,fam=famb,pfam=c(2,-0.01),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1,rep(0,6)),pshape=-0.4,mu=mu,linear=~birth+id,
	fam=famt,pfam=c(2,-0.01),wt=wt)
gnlr3(y,"Burr",pmu=c(5.3,-0.08),pshape=c(0.3,-0.0001),mu=mub,sh=famt,fam=famt,
	pfam=c(4.5,-0.02),wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=0.3,mu=mub,fam=famb,pfam=c(9,-0.04),wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=c(0.3,0.001),mu=mub,sh=famb,fam=famb,
	pfam=c(9,-0.04),wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mubt,pfam=1,wt=wt)
gnlr3(y,"Burr",pmu=c(3,-0.1),pshape=-0.4,mu=mubt,fam=famt,pfam=c(2,-0.01),
	wt=wt)
gnlr3(y,"Burr",pmu=c(5.3,-0.08),pshape=c(0.3,-0.0001),mu=mubt,sh=famt,fam=famt,
	pfam=c(4.5,-0.02),wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=0.3,mu=mubt,fam=fambt,pfam=c(9,-0.04),
	wt=wt)
gnlr3(y,"Burr",pmu=c(9,-0.04),pshape=c(0.3,0.001),mu=mubt,sh=fambt,fam=fambt,
	pfam=c(9,-0.04),wt=wt)

# number of unique uncensored observations = 25
length(unique(y[y[,2]>0,1]))

# number of ties = 36
sum(response(tt)==0)

# number censored/number = 7/7
length(cens)-sum(cens)
length(cens)
